@@ -19,6 +19,11 @@
 # 02110-1301, USA.
 #
 
+from __future__ import absolute_import
+from __future__ import division
+from __future__ import print_function
+from __future__ import unicode_literals
+
 import os
 import platform
 import re
@@ -113,7 +118,8 @@ def _resolve_non_libtool(options, binary, libraries):
 
         shlibs = []
         for line in proc.stdout:
-            for library, pattern in patterns.iteritems():
+            line = line.decode('ascii')
+            for library, pattern in patterns.items():
                 m = pattern.search(line)
                 if m:
                     del patterns[library]
