@@ -17,6 +17,10 @@
 # Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 # Boston, MA 02111-1307, USA.
 #
+from __future__ import absolute_import
+from __future__ import division
+from __future__ import print_function
+from __future__ import unicode_literals
 
 import errno
 import re
@@ -155,7 +159,7 @@ def get_libtool_command(options):
         libtool_cmd = 'glibtool'
     try:
         subprocess.check_call([libtool_cmd, '--version'],
-                              stdout=open(os.devnull))
+                              stdout=open(os.devnull, 'w'))
     except (subprocess.CalledProcessError, OSError):
         # If libtool's not installed, assume we don't need it
         return None
@@ -164,10 +168,10 @@ def get_libtool_command(options):
 
 
 def files_are_identical(path1, path2):
-    with open(path1) as f1, open(path2) as f2:
+    with open(path1, 'rb') as f1, open(path2, 'rb') as f2:
         buf1 = f1.read(8192)
         buf2 = f2.read(8192)
-        while buf1 == buf2 and buf1 != '':
+        while buf1 == buf2 and buf1 != b'':
             buf1 = f1.read(8192)
             buf2 = f2.read(8192)
         return buf1 == buf2
@@ -224,7 +228,7 @@ def makedirs(name, mode=0o777, exist_ok=False):
     if head and tail and not os.path.exists(head):
         try:
             makedirs(head, mode, exist_ok)
-        except OSError as e:
+        except (IOError, OSError) as e:
             # be happy if someone already created the path
             if e.errno != errno.EEXIST:
                 raise
@@ -232,7 +236,7 @@ def makedirs(name, mode=0o777, exist_ok=False):
             return
     try:
         os.mkdir(name, mode)
-    except OSError as e:
+    except (IOError, OSError) as e:
         if not exist_ok or e.errno != errno.EEXIST or not os.path.isdir(name):
             raise
 
